.. include:: links.rst

Contributing
------------

|TatSu| development is done on Github_. Bug reports, patches, suggestions, and improvements are welcome.

.. _Github : https://github.com/neogeny/TatSu


Donations
~~~~~~~~~

|donate|

If you'd like to contribute to the future development of |TatSu|,
please `make a donation`_ to the project.

Some of the planned new features are: grammar expressions for left
and right associativity, new algorithms for left-recursion, a
unified intermediate model for parsing and translating programming
languages, and more...

.. |donate| image:: _static/images/btn_donate_SM.gif
   :target: https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=2TW56SV6WNJV6
